@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.1303';
+our $VERSION = '0.1304';
 
 use strict;
 use warnings;
@@ -318,7 +318,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.1303
+version 0.1304
 
 =head1 SYNOPSIS
 
@@ -506,8 +506,8 @@ not rendered and used.
 
   play_fluidsynth($score_obj, $midi_file, $soundfont, \@config);
 
-Play a given B<score> named B<midi_file> with C<timidity> and a
-B<soundfont> file and optional system B<config> options.
+Play a given B<score> named B<midi_file> with C<fluidsynth> and a
+B<soundfont> file and optional system B<config>.
 
 For C,darwin> is is C<-a coreaudio -m coremidi>. For linux systems,
 this is C<-a alsa -m alsa_seq>.
@@ -545,11 +545,11 @@ L<Music::Tempo>
 
 =head1 AUTHOR
 
-Gene Boggs <gene@cpan.org>
+Gene Boggs <gene.boggs@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2024 by Gene Boggs.
+This software is copyright (c) 2019-2025 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
